LaunchConfig

Struct LaunchConfig 

pub struct LaunchConfig { /* private fields */ }
Cloneable description of an application to launch.

Implementations

Source

impl LaunchConfig

pub fn new(program: impl Into<OsString>) -> Self

Create a launch configuration for an executable name or path.

Examples found in repository?
examples/basic.rs (line 15)
5fn main() -> Result<(), Box<dyn std::error::Error>> {
6    let mut arguments = std::env::args_os().skip(1);
7    let program = arguments
8        .next()
9        .unwrap_or_else(|| "gnome-calculator".into());
10    let harness = ComputerUse::builder()
11        .native_timeout(Duration::from_secs(8))
12        .fallback_timeout(Duration::from_secs(30))
13        .bridge_geometry(1280, 800)
14        .build()?;
15    let mut app = harness.launch(LaunchConfig::new(program).args(arguments))?;
16
17    let frame = app.capture()?;
18    println!(
19        "controlled pid={} transport={:?} frame={}x{}",
20        app.pid(),
21        app.transport(),
22        frame.width,
23        frame.height
24    );
25    frame.image.save("agent-seat-frame.png")?;
26
27    // Harmlessly focus the center of the captured app to prove pointer input.
28    app.click(
29        f64::from(frame.width) / 2.0,
30        f64::from(frame.height) / 2.0,
31        PointerButton::Left,
32        1,
33    )?;
34
35    app.stop();
36    Ok(())
37}
More examples
Hide additional examples
examples/agent_loop.rs (line 16)
10fn main() -> Result<(), Box<dyn std::error::Error>> {
11    let mut args = env::args().skip(1);
12    let program = args
13        .next()
14        .unwrap_or_else(|| "gnome-calculator".to_string());
15
16    let mut config = LaunchConfig::new(&program);
17    for extra in args {
18        config = config.arg(extra);
19    }
20
21    let harness = ComputerUse::new()?;
22    let mut app = harness.launch(config)?;
23    println!("launched {program} via {:?}", app.transport());
24
25    // 1. Perceive: capture the initial frame.
26    let before = app.capture()?;
27    before.image.save("agent-loop-before.png")?;
28    println!(
29        "captured {}x{} -> agent-loop-before.png",
30        before.image.width(),
31        before.image.height()
32    );
33
34    // 2. Act: focus, select-all, and type, exercising keyboard + text paths.
35    app.click(
36        before.image.width() as f64 / 2.0,
37        before.image.height() as f64 / 2.0,
38        PointerButton::Left,
39        1,
40    )?;
41    app.press_key("ctrl+a")?;
42    app.type_text("agent-seat-linux")?;
43
44    // 3. Perceive again: capture the post-action frame.
45    let after = app.capture()?;
46    after.image.save("agent-loop-after.png")?;
47    println!(
48        "captured {}x{} -> agent-loop-after.png",
49        after.image.width(),
50        after.image.height()
51    );
52
53    // 4. Teardown: stop the app, then close the seat.
54    app.stop();
55    harness.close();
56    println!("done");
57    Ok(())
58}
pub fn arg(self, argument: impl Into<OsString>) -> Self

Append one command-line argument.

Examples found in repository?
examples/agent_loop.rs (line 18)
10fn main() -> Result<(), Box<dyn std::error::Error>> {
11    let mut args = env::args().skip(1);
12    let program = args
13        .next()
14        .unwrap_or_else(|| "gnome-calculator".to_string());
15
16    let mut config = LaunchConfig::new(&program);
17    for extra in args {
18        config = config.arg(extra);
19    }
20
21    let harness = ComputerUse::new()?;
22    let mut app = harness.launch(config)?;
23    println!("launched {program} via {:?}", app.transport());
24
25    // 1. Perceive: capture the initial frame.
26    let before = app.capture()?;
27    before.image.save("agent-loop-before.png")?;
28    println!(
29        "captured {}x{} -> agent-loop-before.png",
30        before.image.width(),
31        before.image.height()
32    );
33
34    // 2. Act: focus, select-all, and type, exercising keyboard + text paths.
35    app.click(
36        before.image.width() as f64 / 2.0,
37        before.image.height() as f64 / 2.0,
38        PointerButton::Left,
39        1,
40    )?;
41    app.press_key("ctrl+a")?;
42    app.type_text("agent-seat-linux")?;
43
44    // 3. Perceive again: capture the post-action frame.
45    let after = app.capture()?;
46    after.image.save("agent-loop-after.png")?;
47    println!(
48        "captured {}x{} -> agent-loop-after.png",
49        after.image.width(),
50        after.image.height()
51    );
52
53    // 4. Teardown: stop the app, then close the seat.
54    app.stop();
55    harness.close();
56    println!("done");
57    Ok(())
58}
pub fn args<I, S>(self, arguments: I) -> Self
where I: IntoIterator<Item = S>, S: Into<OsString>,

Append several command-line arguments.

Examples found in repository?
examples/basic.rs (line 15)
5fn main() -> Result<(), Box<dyn std::error::Error>> {
6    let mut arguments = std::env::args_os().skip(1);
7    let program = arguments
8        .next()
9        .unwrap_or_else(|| "gnome-calculator".into());
10    let harness = ComputerUse::builder()
11        .native_timeout(Duration::from_secs(8))
12        .fallback_timeout(Duration::from_secs(30))
13        .bridge_geometry(1280, 800)
14        .build()?;
15    let mut app = harness.launch(LaunchConfig::new(program).args(arguments))?;
16
17    let frame = app.capture()?;
18    println!(
19        "controlled pid={} transport={:?} frame={}x{}",
20        app.pid(),
21        app.transport(),
22        frame.width,
23        frame.height
24    );
25    frame.image.save("agent-seat-frame.png")?;
26
27    // Harmlessly focus the center of the captured app to prove pointer input.
28    app.click(
29        f64::from(frame.width) / 2.0,
30        f64::from(frame.height) / 2.0,
31        PointerButton::Left,
32        1,
33    )?;
34
35    app.stop();
36    Ok(())
37}
pub fn env(self, key: impl Into<OsString>, value: impl Into<OsString>) -> Self

Set one environment variable for the application.

pub fn env_remove(self, key: impl Into<OsString>) -> Self

Remove one inherited environment variable from the application.

pub fn current_dir(self, directory: impl Into<PathBuf>) -> Self

Set the application’s working directory.

pub fn inherit_diagnostics(self, inherit: bool) -> Self

Inherit stdout and stderr, which is useful while integrating a new toolkit. They are null by default so controlled apps do not block on closed harness pipes.

pub fn program(&self) -> &OsStr

Executable configured for this launch.