pub struct XwaylandBridge { /* private fields */ }Expand description
One authenticated, rootful XWayland server connected through the private agent seat. It is used as a compatibility bridge only when a native Wayland client cannot expose a readable application frame.
Implementations
Sourceimpl XwaylandBridge
impl XwaylandBridge
The owner-only Xauthority file clients must use.
Sourcepub fn configure_command<'a>(&self, command: &'a mut Command) -> &'a mut Command
pub fn configure_command<'a>(&self, command: &'a mut Command) -> &'a mut Command
Configure a child process to connect exclusively to this XWayland
bridge. Call AgentSeat::adopt_xwayland_bridge after the client has
connected successfully.